@@ -2,7 +2,6 @@ from ._BasicGraph import BasicGraph
 from .graph_style.NodeStyle import NodeStyle
 from .graph_style.EdgeStyle import EdgeStyle
 from .graph_style.RootAndBranchStylist import RootAndBranchStylist
-import graphviz
 from graphviz import Source, Graph as GraphvizGraph, Digraph
 import os
 from functools import wraps
@@ -536,6 +535,15 @@ class Graph(BasicGraph):
 	def render(
 			self, path=None, view=True, direction=None, height=None, width=None, dpi=300, pad=None
 	):
+		"""
+		:type direction: NoneType or str
+		:type dpi: NoneType or int
+		:type height: NoneType of int or float
+		:type width: NoneType or int or float
+		:type pad: NoneType or int or float
+		:type output_format: str or NoneType
+		:rtype: Source
+		"""
 		direction = direction or self._direction
 
 		self.stylize()
@@ -545,10 +553,47 @@ class Graph(BasicGraph):
 		else:
 			filename, file_extension = os.path.splitext(path)
 			output_format = file_extension.lstrip('.')
-			to_save = self.get_graphviz_source(format=output_format)
+			to_save = self.get_graphviz_source(
+				direction=direction, pad=pad, dpi=dpi, height=height, width=width, output_format=output_format
+			)
 			to_save.render(filename=filename, view=view)
-			graphviz_str_to_display = self.get_graphviz_source(direction=direction, pad=pad, dpi=None)
-			return graphviz_str_to_display
+			return self.get_graphviz_source(direction=direction, pad=pad, dpi=None)
+
+	def get_svg(self, direction=None, pad=None, **kwargs):
+		"""
+		:type direction: NoneType or str
+		:type pad: NoneType or int or float
+		:rtype: str
+		"""
+		return self.render(direction=direction, pad=pad, **kwargs)._repr_svg_()
+
+	def get_html(self, direction=None, pad=None, **kwargs):
+		from IPython.core.display import HTML
+		return HTML(self.get_svg(direction=direction, pad=pad, **kwargs))
+
+	def display_html(self, direction=None, pad=None, echo_errors=False, **kwargs):
+		"""
+		:type direction: NoneType or str
+		:type pad: NoneType or int or float
+		:type echo_errors: bool
+		:rtype: str
+		"""
+		try:
+			return displayHTML(self.get_svg(direction=direction, pad=pad, **kwargs))
+		except Exception as e:
+			if echo_errors:
+				print('Could not use displayHTML!')
+				print(e)
+
+			html = self.get_html(direction=direction, pad=pad, **kwargs)
+			try:
+				return display(html)
+			except Exception as e:
+				if echo_errors:
+					print('Coult not use display!')
+					print(e)
+				from IPython.core.display import display as ipython_display
+				return ipython_display(html)
 
 	def get_graphviz_source(self, direction=None, dpi=300, height=None, width=None, pad=None, output_format=None):
 		"""
@@ -568,47 +613,6 @@ class Graph(BasicGraph):
 			)
 			return Source(source=graphviz_str_to_save, format=output_format)
 
-	def get_graphviz_graph(self, direction=None, dpi=300, height=None, width=None, pad=None, output_format=None):
-		"""
-		:type direction: NoneType or str
-		:type dpi: NoneType or int
-		:type height: NoneType of int or float
-		:type width: NoneType or int or float
-		:type pad: NoneType or int or float
-		:type output_format: str or NoneType
-		:rtype: GraphvizGraph or Digraph
-		"""
-		source = self.get_graphviz_source(
-			direction=direction, dpi=dpi, height=height, width=width, pad=pad, output_format=output_format
-		)
-		lst = str(source).splitlines()
-		has_comment = (lst[0].find('//') != -1)
-		is_direct_graph = False
-		skip_index = 0
-
-		if has_comment:
-			skip_index = 1
-			if lst[skip_index].find('graph {') != -1:
-				is_direct_graph = False
-		else:
-			if lst[0].find('graph {') != -1:
-				is_direct_graph = False
-
-		if is_direct_graph:
-			graph = Digraph()
-		else:
-			graph = GraphvizGraph()
-
-		graph.body.clear()
-
-		s = str()
-		for i in range(len(lst)):
-			if ((i > skip_index) and (i != len(lst) - 1)):
-				if has_comment:
-					graph.comment = lst[0].replace('//', '')
-				graph.body.append(lst[i])
-		return graph
-
 	def display(self, p=None, pad=0.2, direction=None, path=None, height=None, width=None, dpi=300):
 		try:
 			from IPython.core.display import display
